@@ -1,4 +1,4 @@
-/*	$OpenBSD: extern.h,v 1.116 2022/01/28 15:30:23 claudio Exp $ */
+/*	$OpenBSD: extern.h,v 1.125 2022/04/04 16:02:54 claudio Exp $ */
 /*
  * Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -160,6 +160,7 @@ enum rtype {
 	RTYPE_CER,
 	RTYPE_CRL,
 	RTYPE_GBR,
+	RTYPE_ASPA,
 	RTYPE_REPO,
 	RTYPE_FILE,
 };
@@ -280,7 +281,8 @@ struct crl {
 	RB_ENTRY(crl)	 entry;
 	char		*aki;
 	X509_CRL	*x509_crl;
-	time_t		 expires; /* do not use after */
+	time_t		 issued;	/* do not use before */
+	time_t		 expires;	/* do not use after */
 };
 /*
  * Tree of CRLs sorted by uri
@@ -420,9 +422,10 @@ struct tal	*tal_read(struct ibuf *);
 
 void		 cert_buffer(struct ibuf *, const struct cert *);
 void		 cert_free(struct cert *);
-struct cert	*cert_parse(const char *, const unsigned char *, size_t);
-struct cert	*ta_parse(const char *, const unsigned char *, size_t,
-		    const unsigned char *, size_t);
+struct cert	*cert_parse_pre(const char *, const unsigned char *, size_t);
+struct cert	*cert_parse(const char *, struct cert *);
+struct cert	*ta_parse(const char *, struct cert *, const unsigned char *,
+		    size_t);
 struct cert	*cert_read(struct ibuf *);
 void		 cert_insert_brks(struct brk_tree *, struct cert *);
 
@@ -447,8 +450,8 @@ struct gbr	*gbr_parse(X509 **, const char *, const unsigned char *,
 		    size_t);
 
 /* crl.c */
-X509_CRL	*crl_parse(const char *, const unsigned char *, size_t);
-void		 free_crl(struct crl *);
+struct crl	*crl_parse(const char *, const unsigned char *, size_t);
+void		 crl_free(struct crl *);
 
 /* Validation of our objects. */
 
@@ -525,7 +528,7 @@ struct repo	*ta_lookup(int, struct tal *);
 struct repo	*repo_lookup(int, const char *, const char *);
 struct repo	*repo_byid(unsigned int);
 int		 repo_queued(struct repo *, struct entity *);
-void		 repo_cleanup(struct filepath_tree *);
+void		 repo_cleanup(struct filepath_tree *, int);
 void		 repo_free(void);
 
 void		 rsync_finish(unsigned int, int);
@@ -576,21 +579,25 @@ struct ibuf	*io_buf_recvfd(int, struct ibuf **);
 /* X509 helpers. */
 
 void		 x509_init_oid(void);
-char		*x509_get_aia(X509 *, const char *);
-char		*x509_get_aki(X509 *, int, const char *);
-char		*x509_get_ski(X509 *, const char *);
+int		 x509_get_aia(X509 *, const char *, char **);
+int		 x509_get_aki(X509 *, const char *, char **);
+int		 x509_get_ski(X509 *, const char *, char **);
 int		 x509_get_expire(X509 *, const char *, time_t *);
-char		*x509_get_crl(X509 *, const char *);
+int		 x509_get_crl(X509 *, const char *, char **);
 char		*x509_crl_get_aki(X509_CRL *, const char *);
 char		*x509_get_pubkey(X509 *, const char *);
 enum cert_purpose	 x509_get_purpose(X509 *, const char *);
+int		 x509_get_time(const ASN1_TIME *, time_t *);
+char		*x509_convert_seqnum(const char *, const ASN1_INTEGER *);
 
 /* printers */
-void		tal_print(const struct tal *);
-void		cert_print(const struct cert *);
-void		mft_print(const struct mft *);
-void		roa_print(const struct roa *);
-void		gbr_print(const struct gbr *);
+char		*time2str(time_t);
+void		 tal_print(const struct tal *);
+void		 cert_print(const struct cert *);
+void		 crl_print(const struct crl *);
+void		 mft_print(const struct mft *);
+void		 roa_print(const struct roa *);
+void		 gbr_print(const struct gbr *);
 
 /* Output! */
 
@@ -621,6 +628,7 @@ void		logx(const char *fmt, ...)
 time_t		getmonotime(void);
 
 int	mkpath(const char *);
+int	mkpathat(int, const char *);
 
 #ifndef RPKI_PATH_TAL_DIR
 #define RPKI_PATH_TAL_DIR	"/etc/rpki"
@@ -642,6 +650,9 @@ int	mkpath(const char *);
 #define RPKI_RSYNC_CMD		"openrsync"
 #endif
 
+/* Maximum number of TAL files we'll load. */
+#define	TALSZ_MAX	8
+
 /* Maximum number of IP and AS ranges accepted in any single file */
 #define MAX_IP_SIZE		200000
 #define MAX_AS_SIZE		200000
@@ -664,4 +675,7 @@ int	mkpath(const char *);
 /* Maximum allowd repositories per tal */
 #define MAX_REPO_PER_TAL	1000
 
+/* Maximum number of delta files per RRDP notification file. */
+#define MAX_RRDP_DELTAS		300
+
 #endif /* ! EXTERN_H */
